[jboss-cvs] JBossCache/tests/stress/org/jboss/cache ...
Manik Surtani
msurtani at jboss.com
Sat Dec 30 12:50:04 EST 2006
User: msurtani
Date: 06/12/30 12:50:04
Modified: tests/stress/org/jboss/cache LocalStressTest.java
EvictionLocalStressTest.java
Log:
Major changes to restructure cache and node object model
Revision Changes Path
1.9 +5 -5 JBossCache/tests/stress/org/jboss/cache/LocalStressTest.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: LocalStressTest.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests/stress/org/jboss/cache/LocalStressTest.java,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -b -r1.8 -r1.9
--- LocalStressTest.java 20 Dec 2006 13:56:49 -0000 1.8
+++ LocalStressTest.java 30 Dec 2006 17:50:04 -0000 1.9
@@ -35,14 +35,14 @@
//import java.text.FieldPosition;
/**
* Local mode stress test for TreeCache.
*
* @author <a href="mailto:bwang at jboss.org">Ben Wang</a> May 20 2003
- * @version $Revision: 1.8 $
+ * @version $Revision: 1.9 $
*/
public class LocalStressTest extends TestCase
{
- static TreeCache cache_;
+ static CacheImpl cache_;
Configuration.CacheMode cachingMode_ = Configuration.CacheMode.LOCAL;
final static Properties p_;
// final static Log log_=LogFactory.getLog(LocalStressTestCase.class);
@@ -101,7 +101,7 @@
void initCaches(Configuration.CacheMode caching_mode) throws Exception
{
cachingMode_ = caching_mode;
- cache_ = new TreeCache();
+ cache_ = new CacheImpl();
cache_.setConfiguration(new XmlConfigurationParser().parseFile("META-INF/local-lru-eviction-service.xml")); // read in generic local xml
cache_.getConfiguration().setTransactionManagerLookupClass("org.jboss.cache.DummyTransactionManagerLookup");
cache_.create();
@@ -259,7 +259,7 @@
}
/**
- * Generate the tree nodes quasi-exponentially. I.e., depth is the level
+ * Generate the cache nodes quasi-exponentially. I.e., depth is the level
* of the hierarchy and children is the number of children under each node.
* This strucutre is used to add, get, and remove for each node.
*/
@@ -35,14 +35,14 @@
//import java.text.FieldPosition;
/**
- * Local mode stress test for TreeCache.
+ * Local mode stress test for CacheImpl.
*
* @author <a href="mailto:bwang at jboss.org">Ben Wang</a> May 20 2003
1.8 +5 -5 JBossCache/tests/stress/org/jboss/cache/EvictionLocalStressTest.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: EvictionLocalStressTest.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests/stress/org/jboss/cache/EvictionLocalStressTest.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -b -r1.7 -r1.8
--- EvictionLocalStressTest.java 15 Sep 2006 15:11:35 -0000 1.7
+++ EvictionLocalStressTest.java 30 Dec 2006 17:50:04 -0000 1.8
@@ -27,14 +27,14 @@
/**
* Local mode stress test for TreeCache.
*
* @author <a href="mailto:bwang at jboss.org">Ben Wang</a> May 20 2003
- * @version $Id: EvictionLocalStressTest.java,v 1.7 2006/09/15 15:11:35 msurtani Exp $
+ * @version $Id: EvictionLocalStressTest.java,v 1.8 2006/12/30 17:50:04 msurtani Exp $
*/
public class EvictionLocalStressTest extends TestCase
{
- static TreeCache cache_;
+ static CacheImpl cache_;
Configuration.CacheMode cachingMode_ = Configuration.CacheMode.LOCAL;
final static Properties p_;
String oldFactory_ = null;
@@ -90,7 +90,7 @@
void initCaches(Configuration.CacheMode caching_mode) throws Exception
{
cachingMode_ = caching_mode;
- cache_ = new TreeCache();
+ cache_ = new CacheImpl();
cache_.setConfiguration(new XmlConfigurationParser().parseFile("META-INF/local-lru-eviction-service.xml")); // read in generic local xml
cache_.getConfiguration().setTransactionManagerLookupClass("org.jboss.cache.DummyTransactionManagerLookup");
LockStrategyFactory.setIsolationLevel(IsolationLevel.REPEATABLE_READ);
@@ -268,7 +268,7 @@
}
/**
- * Generate the tree nodes quasi-exponentially. I.e., depth is the level
+ * Generate the cache nodes quasi-exponentially. I.e., depth is the level
* of the hierarchy and children is the number of children under each node.
* This strucutre is used to add, get, and remove for each node.
*/
@@ -27,14 +27,14 @@
/**
- * Local mode stress test for TreeCache.
+ * Local mode stress test for CacheImpl.
*
* @author <a href="mailto:bwang at jboss.org">Ben Wang</a> May 20 2003
More information about the jboss-cvs-commits
mailing list